@@ -2,8 +2,8 @@ import json
 import logging
 import requests
 from  urllib.parse import ParseResult
-from typing import Dict
-
+from typing import Dict, List, Tuple, TYPE_CHECKING, Union
+import urllib3
 from deepdriver.sdk import util
 from deepdriver import logger
 import deepdriver.version as version
@@ -11,9 +11,11 @@ URL_LOGIN = "/api/client/auth"
 URL_CREATE = "/api/client/experiment/create"
 URL_CREATE_HPO = "/api/client/experiment/create/hpo"
 URL_GET_HPO = "/api/client/experiment/get/hpo"
+URL_UPLOAD_LOG = "/api/client/run/log/upload"
+URL_UPDATE_CONFIG = "/api/client/run/config/update"
 URL_FINISH = "/api/client/run/finish"
 
-
+urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 jwt_key: str = None
 use_http: bool =False
@@ -118,6 +120,32 @@ def get_hpo(http_host:str, exp_name: str="", team_name: str="") -> Dict:
     logger.debug("get_hpo() response : " + rsp["message"])
     return rsp
 
+def upload_log(http_host:str, run_id: int , exp_name: str, team_name: str , step: int , item_dict: Dict[str, Union[int, str, float, bool]] ) -> Dict:
+    item_list = [{"key": k, "value": v} for k, v in item_dict.items()] if item_dict else []
+    data = {
+        "teamName": team_name,
+        "expName": exp_name,
+        "runId" : run_id,
+        "step" : step,
+        "items" :item_list,
+    }
+    url = parse_result_wraaper(http_host,URL_UPLOAD_LOG)
+    rsp = post(url, data)
+    logger.debug("upload_log() response : " + rsp["message"])
+    return rsp
+
+def update_config(http_host:str, run_id: int , exp_name: str, team_name: str , items: list):
+    item_list = [{"key": k, "value": v} for (k, v) in items] if items else []
+    data = {
+        "teamName": team_name,
+        "expName": exp_name,
+        "runId" : run_id,
+        "items" : item_list,
+    }
+    url = parse_result_wraaper(http_host,URL_UPDATE_CONFIG)
+    rsp = post(url, data)
+    logger.debug("update_config() response : " + rsp["message"])
+    return rsp
 
 def finish(http_host: str ,data: Dict) -> Dict:
     url = parse_result_wraaper(http_host,URL_FINISH)
