@@ -19,6 +19,12 @@ if TYPE_CHECKING:
     from deepdriver.sdk.artifact import Artifact
 
 stub: ResourceStub = None
+grpc_host : str = None
+use_grpc : bool = False
+use_grpc_tls : bool = False # GPRC의 tls(ssl) 사용여부
+use_https : bool = False
+cert_path: str = None
+http_host : str = None
 
 def set_stub(stub_: ResourceStub) -> None:
     global stub
@@ -29,11 +35,6 @@ def get_stub() -> ResourceStub:
     global stub
     return stub
 
-grpc_host : str = "127.0.0.1:19051"
-use_grpc_tls : bool = False # GPRC의 tls(ssl) 사용여부
-use_https : bool = False
-cert_path: str = None
-
 def set_grpc_host(grpc_host_: str, use_grpc_tls_=False) -> None:
     global grpc_host
     global use_grpc_tls
@@ -62,7 +63,13 @@ def get_use_https() -> bool:
     global use_https
     return use_https
 
-http_host = "127.0.0.1:9011"
+def set_use_grpc(use_grpc_: bool) -> None:
+    global use_grpc
+    use_grpc = use_grpc_
+
+def get_use_grpc() -> bool:
+    global use_grpc
+    return use_grpc
 
 def set_http_host(http_host_: str, use_https_ = False) -> None:
     global http_host
@@ -74,7 +81,6 @@ def set_http_host(http_host_: str, use_https_ = False) -> None:
     use_https =use_https_
     http_interface.set_use_https(use_https)
 
-
 def get_http_host() -> str:
     global http_host
     return http_host
@@ -85,39 +91,47 @@ def get_http_host_ip() -> str:
 
 
 def update_config(run_id: int, team_name: str, exp_name: str, config_item_list: list(Tuple)):
-    def makeItem(item):
-        key, value = item
-        if isinstance(value, int):
-            if value > 2 ** 32 - 1:  # check type long
-                configItem = ConfigItem(key=key, valueAsLong=value)
-            else:
-                configItem = ConfigItem(key=key, valueAsInt=value)
-        elif isinstance(value, str):
-            configItem = ConfigItem(key=key, valueAsString=value)
-        elif isinstance(value, float):
-            configItem = ConfigItem(key=key, valueAsFloat=value)
-        elif isinstance(value, bool):
-            configItem = ConfigItem(key=key, valueAsBool=value)
-        elif isinstance(value, dict) or isinstance(value, list):
-            configItem = ConfigItem(key=key, valueAsString=json.dumps(value))
-        return configItem
-
     # client 정보 추가
     import deepdriver.version as version
     config_item_list.append(('cliVer', version.__version__))
     config_item_list.append(('pythonVer', util.get_python_version()))
 
+    if get_use_grpc():
+        def makeItem(item):
+            key, value = item
+            if isinstance(value, int):
+                if value > 2 ** 32 - 1:  # check type long
+                    configItem = ConfigItem(key=key, valueAsLong=value)
+                else:
+                    configItem = ConfigItem(key=key, valueAsInt=value)
+            elif isinstance(value, str):
+                configItem = ConfigItem(key=key, valueAsString=value)
+            elif isinstance(value, float):
+                configItem = ConfigItem(key=key, valueAsFloat=value)
+            elif isinstance(value, bool):
+                configItem = ConfigItem(key=key, valueAsBool=value)
+            elif isinstance(value, dict) or isinstance(value, list):
+                configItem = ConfigItem(key=key, valueAsString=json.dumps(value))
+            return configItem
+
+
+
+        item = map(makeItem, config_item_list)
+        rsp: UpdateConfigResponse = get_stub().update_config(UpdateConfigRequest(
+            runId=run_id,
+            item=item,
+            teamName=team_name,
+            expName=exp_name,
+            authorization=f"Bearer {http_interface.get_jwt_key()}",
+        ))
+        return rsp.rsp_result.result == "success"
+
+    else:
+        rsp =http_interface.update_config(http_host=get_http_host(), run_id=run_id, items=config_item_list, team_name=team_name,
+                                  exp_name=exp_name)
+        return rsp["result"] == "success"
 
-    item = map(makeItem, config_item_list)
-    rsp: UpdateConfigResponse = get_stub().update_config(UpdateConfigRequest(
-        runId=run_id,
-        item=item,
-        teamName=team_name,
-        expName=exp_name,
-        authorization=f"Bearer {http_interface.get_jwt_key()}",
-    ))
 
-    return rsp.rsp_result.result == "success"
 
 
 def send_alert(run_id: int, team_name: str, exp_name: str, alert_msg: str):
@@ -132,36 +146,41 @@ def send_alert(run_id: int, team_name: str, exp_name: str, alert_msg: str):
 
 def upload_log(run_id: int, team_name: str, exp_name: str, log_step: int, item_dict: Dict[str, Union[int, str, float, bool]]) -> bool:
     item_list = []
-
-    def makeItem(item):
-        key, value = item
-        if isinstance(value, int):
-            if value > 2 ** 32 - 1:  # check type long
-                logItem = LogItem(key=key, valueAsLong=value)
+    if get_use_grpc():
+        def makeItem(item):
+            key, value = item
+            if isinstance(value, int):
+                if value > 2 ** 32 - 1:  # check type long
+                    logItem = LogItem(key=key, valueAsLong=value)
+                else:
+                    logItem = LogItem(key=key, valueAsInt=value)
+            elif isinstance(value, str):
+                logItem = LogItem(key=key, valueAsString=value)
+            elif isinstance(value, float):
+                logItem = LogItem(key=key, valueAsFloat=value)
+            elif isinstance(value, bool):
+                logItem = LogItem(key=key, valueAsBool=value)
             else:
-                logItem = LogItem(key=key, valueAsInt=value)
-        elif isinstance(value, str):
-            logItem = LogItem(key=key, valueAsString=value)
-        elif isinstance(value, float):
-            logItem = LogItem(key=key, valueAsFloat=value)
-        elif isinstance(value, bool):
-            logItem = LogItem(key=key, valueAsBool=value)
-        else:
-            raise Exception("value는 int, str, float, bool 타입만 가능합니다.")
-        return logItem
+                raise Exception("value는 int, str, float, bool 타입만 가능합니다.")
+            return logItem
+
+        item = map(makeItem, item_dict.items())
+
+        # item = [LogItem(key=key, value=str(value)) for key, value in item_dict.items()]
+        rsp: UploadLogResponse = get_stub().upload_log(UploadLogRequest(
+            item=item,
+            step=LogStep(num=log_step),
+            run=RunInfo(run_id=run_id),
+            teamName=team_name,
+            expName=exp_name,
+            authorization=f"Bearer {http_interface.get_jwt_key()}",
+        ))
+        return rsp.rsp_result.result == "success"
+    else:
+        rsp = http_interface.upload_log(http_host=get_http_host(),run_id =run_id, item_dict =item_dict, team_name=team_name,exp_name=exp_name, step =log_step )
+        return rsp["result"] == "success"
 
-    item = map(makeItem, item_dict.items())
 
-    # item = [LogItem(key=key, value=str(value)) for key, value in item_dict.items()]
-    rsp: UploadLogResponse = get_stub().upload_log(UploadLogRequest(
-        item=item,
-        step=LogStep(num=log_step),
-        run=RunInfo(run_id=run_id),
-        teamName=team_name,
-        expName=exp_name,
-        authorization=f"Bearer {http_interface.get_jwt_key()}",
-    ))
-    return rsp.rsp_result.result == "success"
 
 
 CHUNK_SIZE = 4* 1024 * 1024  # 8MB
